
# relationship between somatic depth and morphological features
# figure 2E

tmpMatch <- c("ITi" = "IT", "ITc"="IT", "PT"="PT", "CT"="CT")

df <- 
  data.frame(Group = tmpMatch[match(dendrite_info$Type[Index_apical_tmp], names(tmpMatch))],
             Region = dendrite_info$BrainRegion[Index_apical_tmp],
             Soma_depth = depth_soma_W$depth_som_Wa[Index_apical_tmp],
             Tuft_length = feature_all$arbor.Length[Index_apical_tmp],
             Basal_length = feature_all$basal_cable.length[Index_apical_tmp],
             Trunk_length = feature_all$trunk.Length[Index_apical_tmp])


p <- 
  ggplot(data = df, mapping = aes(x = Soma_depth, y = Basal_length, group = Group, color = Group)) + 
  #facet_wrap(facets = "Group") +
  geom_point(mapping = aes(color = Group)) +
  geom_smooth(method = "lm") +
  theme_classic() +
  theme(axis.title.x = element_text(size = 20), 
        axis.text.x = element_text(size = 12),
        axis.title.y = element_text(size = 20), 
        axis.text.y = element_text(size = 12),
        legend.position = "left") +
  scale_x_continuous(breaks = get_breaks(n = 8), limits = c(0,1)) + 
  scale_color_manual(values = c("orange", "red", "blue")) +
  #scale_y_continuous(breaks = get_breaks(n = 6), limits = c(0, 5e5)) +
  ggpmisc::stat_fit_glance(method = "lm",
                           geom = "text_npc",
                           aes(label = paste0("P=", signif(..p.value.., digits = 4))),
                           label.x = "left",
                           label.y = "top") +
  ggpmisc::stat_poly_eq(aes(label = paste0(..rr.label..)), label.x = "right", label.y = "top")


ggExtra::ggMarginal(p = p, groupColour = TRUE, groupFill = TRUE, margins = "y")



# 
# tttt <- df %>%
#   dplyr::group_by(Group) %>%
#   dplyr::summarise_at(.vars = c("Tuft_length"),
#                       list(mean))
# 


model <- aov(formula = Tuft_length ~ Group, data = df)
TukeyHSD(model, conf.level = 0.95)

model <- aov(formula = Basal_length ~ Group, data = df)
TukeyHSD(model, conf.level = 0.95)

model <- aov(formula = Dendrite_length ~ Group, data = df)
TukeyHSD(model, conf.level = 0.95)









