# L2/3 NPy neurons
# Figure 3


Index_L23_NPy <- which(dendrite_info$Comment %in% 
                     c("Multipolar+L1+0", "Multipolar+L1+1", 
                       "Multipolar+L1+2", "Multipolar+L1+3"))

# Note some neurons are located in L5A 
# Index_L23_NPy <- Index_L23_NPy[which(dendrite_info$W[Index_L23_NPy] %in% c(1,2,3))]

# 
# Index_L23_Py <- 
#   base::intersect(which(dendrite_info$IsApicalDendriteVisible == "Yes"),
#                   which(dendrite_info$W %in% c(1,2,3)))


Index_L23_Py <- which(dendrite_info$IsApicalDendriteVisible == "Yes") %>%
  base::intersect(which(dendrite_info$W %in% c(1,2,3))) %>%
  base::intersect(which(depth_soma_W$depth_som_Wa < 0.5))
  

Index_L23_all <- c(Index_L23_NPy, Index_L23_Py)


# Figure 3A updated annotation of L2/3 non-pyramidal neurons ----

asdf <- read.table("~/Non-pyramidal_L23.csv", header = T, sep = ",")


label_neuron_L23 <- matrix(nrow = length(Index_L23_NPy), ncol = 1)
for(iNeuron in 1:length(Index_L23_NPy)) {
  label_neuron_L23[iNeuron, 1] <- 8
  if(asdf$NumberOfMainDendrites[iNeuron] == 1 && asdf$Orientation[iNeuron] == "H") {
    label_neuron_L23[iNeuron, 1] <- 1
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 2 && asdf$Orientation[iNeuron] == "H1") {
    label_neuron_L23[iNeuron, 1] <- 2
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 2 && asdf$Orientation[iNeuron] == "H2") {
    label_neuron_L23[iNeuron, 1] <- 3
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 2 && asdf$Orientation[iNeuron] == "V") {
    label_neuron_L23[iNeuron, 1] <- 4
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 3 && asdf$Orientation[iNeuron] == "V") {
    label_neuron_L23[iNeuron, 1] <- 5
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 0 && asdf$Orientation[iNeuron] == "Fan") {
    label_neuron_L23[iNeuron, 1] <- 6
  }
  if(asdf$NumberOfMainDendrites[iNeuron] == 0 && asdf$Orientation[iNeuron] == "Stellate") {
    label_neuron_L23[iNeuron, 1] <- 7
  }
}


group_neuron_L23 <- c(label_neuron_L23, rep(9, length(Index_L23_Py)))


df <- data.frame(
  Group = factor(x = group_neuron_L23, levels = c(1,2,3,4,5,6,7,8,9)),
  Height = feature_all$dn[Index_L23_all],
  Width = feature_all$v1[Index_L23_all])

df$Ratio <- df$Width / df$Height


Index_subtype_678 <- which(df$Group %in% c(6,7,8) == TRUE)

index_group_1 <- Index_subtype_678[which(df$Ratio[Index_subtype_678] > 1.5)]
index_group_2 <- Index_subtype_678[which(df$Ratio[Index_subtype_678] < 1.5)]


if(0) {
open3d()
plot_morphology(neuronList = DendriteList_allen[Index_L23_all[index_group_1]], 
                hemisphere = dendrite_info$Hemisphere[Index_L23_all[index_group_1]],
                flip = TRUE, soma_size = 10, color = "red")

plot_morphology(neuronList = DendriteList_allen[Index_L23_all[index_group_2]], 
                hemisphere = dendrite_info$Hemisphere[Index_L23_all[index_group_2]],
                flip = TRUE, soma_size = 10, color = "blue")


table(dendrite_info$W[Index_L23_all[index_group_1]])
table(dendrite_info$W[Index_L23_all[index_group_2]])
}



group_neuron_L23[index_group_1] <- 6
group_neuron_L23[index_group_2] <- 7


if(0) {
 
  tmpMatch <- c("1"="Horizontal_Pyramidal-like", 
                "2"="Horizontal_Obtuse angle",
                "3"="Horizontal_Acute angle", 
                "4"="Vertical-Two main dendrites",
                "5"="Vertical-Three main dendrites",
                "6"="Horizontal_Multipolar",
                "7"="Vertical_Multipolar")

  info_L23_Npy <- 
    data.frame(SampleID = dendrite_info$SampleID[Index_L23_NPy], 
               Index = dendrite_info$NeuronID[Index_L23_NPy], 
               Label = tmpMatch[match(group_neuron_L23[1:211], names(tmpMatch))],
               Comment = "L23_NPy")
  
  
}


# 
# Index_L23_all <- c(Index_L23_NPy[which(dendrite_info$W[Index_L23] %in% c(1,2,3))], 
#                    Index_L23_Py)
# 
# group_neuron_L23 <- c(label_neuron_L23[which(dendrite_info$W[Index_L23] %in% c(1,2,3))], 
#                       rep(9, length(Index_L23_Py)))


# Figure 3B laminar distribution of subtypes ----

tmp_color <- read.table(file = "~/shared/color_cluster.txt", sep = ",", comment.char = "")
tmp_color$V1[6] <- "#00ffff"

snp_plot_laminar_distribution(value_laminar = dendrite_info$W[Index_L23_all], 
                              group_label = group_neuron_L23, 
                              group_order = c(1,2,3,6,4,7,5,9),
                              group_color = tmp_color$V1[c(1,2,3,6,4,7,5,9)]
                              )

# 
# 
# 
# p <- ggplot(data = 
#          data.frame(Group = as.factor(group_neuron_L23), 
#                     Depth = depth_soma_W$depth_som_Wa[Index_L23_all],
#                     Height = feature_all$dn[Index_L23_all],
#                     Width = feature_all$v1[Index_L23_all],
#                     Area = feature_all$v1[Index_L23_all] * feature_all$v2[Index_L23_all],
#                     Ratio = feature_all$dn[Index_L23_all] / feature_all$v1[Index_L23_all],
#                     Angle_upright = angle_upright[Index_L23_all]),
#        mapping = aes(y = Angle_upright, group = Group, fill = Group)) +
#   geom_boxplot() + 
#   #geom_point(aes(color = Group)) +
#   #geom_smooth(method = "lm")+
#   
#   scale_color_manual(values = tmp_color$V1) +
#   scale_fill_manual(values = tmp_color$V1) +
#   theme_classic()
# 
# ggExtra::ggMarginal(p = p, groupColour = TRUE, groupFill = TRUE)
# 
# 
# 
# plot(x = depth_soma_W$depth_som_Wa[Index_L23], 
#      y = feature_all$v1[Index_L23] / feature_all$dn[Index_L23], 
#      color = c(label_neuron_L23, rep(9, length(Index_L23_NPy))))
# 
# 
# ColorCluster
# 
# 
# 
# plot(x = depth_soma_W$depth_som_Wa[Index_L23], 
#      y = feature_all$v1[Index_L23] / feature_all$dn[Index_L23])
# 


# Figure 3B. Horizontalness  ----
df <- data.frame(
  Group = factor(x = group_neuron_L23, levels = c(1,2,3,6,4,7,5,9)),
  Depth = depth_soma_W$depth_som_Wa[Index_L23_all],
  Height = feature_all$dn[Index_L23_all],
  Width = feature_all$v1[Index_L23_all],
  Angle_Upright = angle_upright[Index_L23_all])

df$Ratio <- df$Width / df$Height
df$Volume <- feature_all$dendrite_Volume[Index_L23_all]


ggplot(data = df, mapping = aes(x = Group, y = Ratio, group = Group, fill = Group)) + 
  geom_boxplot() +
  geom_jitter(width = 0.2)+
  #geom_point(aes(color = Group)) +
  #geom_smooth(method = "lm", formula = y ~ x) +
  theme_classic() +
  theme(axis.text.x = element_text(size = 12), 
        axis.text.y = element_text(size = 12), 
        legend.position = "left") +
#  scale_x_continuous(breaks = get_breaks(n = 8)) + 
  #scale_y_continuous(breaks = get_breaks(n = 6), limits = c(0, 5e5)) +
  scale_fill_manual(values = tmp_color$V1[c(1,2,3,6,4,7,5,8)])  +
  stat_compare_means(ref.group = ".all.", method.args = list(alternative = "greater")) +
  geom_hline(yintercept = mean(df$Ratio))


# 
# 
# ggplot(data = df, mapping = aes(x = Height, y = Width)) + 
#   geom_point(aes(color = Group)) +
#   #geom_smooth(method = "lm", formula = y ~ x) +
#   theme_classic() +
#   theme(axis.text.x = element_text(size = 12), 
#         axis.text.y = element_text(size = 12), 
#         legend.position = "left") +
#   scale_x_continuous(breaks = get_breaks(n = 8)) + 
#   #scale_y_continuous(breaks = get_breaks(n = 6), limits = c(0, 5e5)) +
#   scale_color_manual(values = tmp_color$V1[c(1,2,3,6,4,7,5,8)]) +
#   ggpmisc::stat_fit_glance(method = "lm",
#                            geom = "text_npc",
#                            aes(label = paste0("P=", signif(..p.value.., digits = 4))),
#                            label.x = "left",
#                            label.y = "bottom") +
#   ggpmisc::stat_poly_eq(aes(label = paste0(..rr.label..)), label.x = "right", label.y = "bottom")
# 
# 
# ggExtra::ggMarginal(p = p, groupColour = TRUE, groupFill = TRUE, )


# Figure 3C axonal projection ----
fullname_neuron_L23 <- 
  paste0(dendrite_info$SampleID[Index_L23_all], "-",
         stringr::str_pad(string = dendrite_info$NeuronID[Index_L23_all], 
                          width = 3, side = "left", pad = "0"))

fullname_neuron_all <- 
  paste0(PFC_projection$SampleID, "-",
         stringr::str_pad(string = PFC_projection$Index, 
                          width = 3, side = "left", pad = "0"))

Target_acronym <- c("l_Isocortex", "l_STR", "l_PAL", "l_BLA",
                    "r_Isocortex", "r_STR", "r_PAL", "r_BLA")

axonal_projection_L23 <-
  PFC_projection[match(fullname_neuron_L23, fullname_neuron_all), 
                 snp::getStructureFromAcronym(Target_acronym)]

rownames(axonal_projection_L23) <- fullname_neuron_L23
colnames(axonal_projection_L23) = Target_acronym

# 
# 
# axonal_projection_L23_normalized <- 
#   apply(axonal_projection_L23, 2, FUN = function(x) x / sum(x))
# 
# Heatmap(matrix = axonal_projection_L23_normalized, 
#         cluster_columns = F, 
#         cluster_rows = F, 
#         
#         row_names_side = "left",
#         column_names_side = "top"
# )


tmpMatch_group <- c("1"=1,"2"=2,"3"=3,"8"=8,
                    "4"=4,"5"=5,"6"=6,"7"=7,
                    "9"=9)


## violin plot ----
library(tidyr)

df_DPTs = axonal_projection_L23
# df_DPTs$subtype = factor(x = tmpMatch_group[match(group_neuron_L23, names(tmpMatch_group))], 
#                          levels = c(1,2,3,8,7,6,4,5,9))
df_DPTs$subtype = factor(x = group_neuron_L23, levels = c(1,2,3,6,4,7,5,8))
df_DPTs=pivot_longer(df_DPTs, !subtype, names_to = "target", values_to = "strength")
df_DPTs$target = factor(levels = Target_acronym, x = df_DPTs$target)

## Violin plot 
p=ggplot(df_DPTs, aes(x = subtype, y = strength, fill = subtype)) +
  #geom_boxplot()+
  geom_violin(scale = "width", size = 0.2, adjust = 1, trim = TRUE) +
  stat_summary(fun = "mean",
               geom = "point",
               size = 0.5) +
  facet_wrap(facets = "target", nrow = length(Target_acronym), ncol = 1, 
             strip.position = "left", scale = "free_y") +
  scale_fill_manual(values = tmp_color$V1[c(1,2,3,6,4,7,5,8)])+
  theme_classic() +
  theme(#axis.text.x = element_blank(),
    #axis.line.x = element_blank(),
    #axis.ticks.y = element_blank(),
    #axis.text.y = element_blank(),
    #axis.line.y = element_blank(),
    legend.position = "none",
    strip.background = element_blank(), 
    strip.text.y.left  = element_text(angle = 0),
    #strip.placement = "outside",
    strip.text = element_text(size = 8, angle = 0),
    panel.spacing.y = unit(0, "mm")
  ) +
  #stat_compare_means() +
  stat_compare_means(ref.group = "8", method.args = list(alternative = "two.sided"), label.y = 1)
p



ggplot(data = data.frame(Group = group_neuron_L23,
                         Ratio = axonal_projection_L23$l_BLA / axonal_projection_L23$r_Isocortex),
       mapping = aes(x = Group, y = Ratio, group = Group)) +
  ggboxplot()




mean_subtype_proj = aggregate(x = axonal_projection_L23, by = list(group_neuron_L23), FUN = mean)


mean_subtype_proj_normalized = apply(as.matrix(mean_subtype_proj[,-1]), 2, function(x) x/max(x))
rownames(mean_subtype_proj_normalized) <- 1:8
colnames(mean_subtype_proj_normalized) <- substring(Target_acronym, 3) # Note




Heatmap(matrix = mean_subtype_proj_normalized, 
        row_order = c(1,2,3,6,4,7,5,8),
        row_names_side = "left",
        
        cluster_rows = F,
        
        
        column_names_side = "top",
        
        cluster_columns = F, border = T)




# relationship between axonal projections
AxonalType = c("ITi", "ITc", "PT", "CT")

Label_Group <- group_neuron_L23
Index_apical_tmp <- Index_L23_all

matrix_distribution <- matrix(nrow = 4, ncol = length(unique(Label_Group)))
rownames(matrix_distribution) <- AxonalType

for(iAxonType in 1:4) {
  for(iCluster in 1:length(unique(Label_Group))) {
    matrix_distribution[iAxonType, iCluster] <-
      length(base::intersect(which(dendrite_info$Type[Index_apical_tmp] == 
                                     AxonalType[iAxonType]),
                             which(Label_Group == iCluster)))
  }
}


ratio <- matrix(nrow = 9, ncol = 1)
for(iSubtype in 1:9) {
  tmp_subtype <- dendrite_info$Subtype[Index_L23_all[which(group_neuron_L23 %in% c(iSubtype))]]
  num_19_21 <- length(which(tmp_subtype %in% c(19)))
  ratio[iSubtype,1] <- num_19_21 / length(tmp_subtype)
}





# Figure S3B. Difference among other morphological features ----

feature_set <- c("trunk.Length", "oblique.Num", 
                 "arbor.Length", "basal_cable.length")
#feature_set <- c("arbor.Length")


#Index_feature <- which(colnames(feature_all) %in% feature_set)
Index_feature <- 28:38

library(tidyr)
library(ggpubr)

df_DPTs <- feature_all[Index_L23_all, Index_feature]
df_DPTs$subtype = factor(group_neuron_L23)
df_DPTs=pivot_longer(df_DPTs, !subtype, names_to = "feature", values_to = "strength")
#df_DPTs$feature = factor(x = df_DPTs$feature)


## Violin plot 
p=ggplot(df_DPTs, aes(x = subtype, y = strength, 
                      fill = subtype)) +
   scale_fill_manual(values = tmp_color$V1) +
  geom_boxplot(outlier.shape = NA)+
  #geom_jitter(width = 0.2)+
  #geom_violin(scale = "width", size = 0.2, adjust = 1, trim = TRUE) +
  # stat_summary(fun = "mean",
  #              geom = "point",
  #              size = 0.5) +
  facet_wrap(facets = "feature", nrow = 1, ncol = length(Index_feature),
             strip.position = "top", scale = "free_y") +
  theme_classic() +
  theme(#axis.text.x = element_blank(),
    #axis.line.x = element_blank(),
    #axis.ticks.y = element_blank(),
    #axis.text.y = element_blank(),
    #axis.line.y = element_blank(),
    legend.position = "none",
    strip.background = element_blank(), 
    strip.text.y.left  = element_text(angle = 0),
    strip.placement = "outside",
    strip.text = element_text(size = 8, angle = 0),
    panel.spacing.y = unit(0, "mm")
  ) +
 stat_compare_means()
p
