# figure 4. comparison with neurons from sensory cortex ----


tmpMatch_axon <- c("ITi"="IT", "ITc"="IT", "IT"="IT", "PT"="PT", "CT"="CT")
tmpMatch_ColorSourceRegion <- 
  c("MOs"="red","ACAd"="red","ACAv"="red",
                          "PL"="red","ILA"="red","FRP"="red",
                          "ORBm"="red","ORBvl"="red","ORBl"="red",
                          "AId"="red","AIv"="red",
                          
                          "MOp"="green","SSp-bfd"="green","SSp-ll"="green",
                          "SSp-m"="green","SSp-n"="green","SSp-ul"="green",
                          "SSp-un"="green", "SSp-tr"="green", "SSs"="green",
                          
                          "VISal"="blue", "VISam" = "blue", "VISl"="blue",
                          "VISli"="blue", "VISp" = "blue", "VISpm"="blue",
                          "VISpor"="blue")


df <- data.frame(
  Type = factor(x = tmpMatch_axon[match(asdf$Type, names(tmpMatch_axon))],
                levels = c("IT", "PT", "CT")),
  Total_length = feature_dendrite$dendrite_cable.length,
  Tuft_length = feature_dendrite$arbor.Length,
  Trunk_length = feature_dendrite$trunk.Length,
  Basal_length = feature_dendrite$basal_cable.length,
  Area = factor(x = tmpMatch_ColorSourceRegion[match(asdf$BrainRegion, 
                                          names(tmpMatch_ColorSourceRegion))],
                levels = c("red", "green", "blue")))



ggplot(data = df, mapping = aes(x = Type, y = Basal_length, group = Type, fill = Type)) +
  facet_wrap(facets = "Area") +
  geom_boxplot() +
  theme_classic() +
  theme(axis.ticks.length = unit(2, "mm")) +
  stat_compare_means(comparisons = list(c("IT", "PT"), c("IT", "CT"), c("PT", "CT")))


ggline(data = dddd, x = "Area", y = "Value", color = "Feature", add = c("mean_sd"), facet.by = "Type") +
  facet_wrap("Type")


res.aov2 <- aov(Basal_length ~ Type * Area, data = df)
summary(res.aov2)


ggplot(data = df, mapping = aes(x = Area, y = Tuft_length, group = Area, fill = Area)) +
  facet_wrap(facets = "Type", scale = "free_y") +
  geom_boxplot() +
  scale_fill_manual(values = c("red", "green", "blue")) +
  theme_classic() +
  theme(axis.ticks.length = unit(2, "mm")) +
  stat_compare_means(comparisons = list(c("red", "green"), 
                                        c("red", "blue"), 
                                        c("green", "blue")))








axon_class <- c("IT", "PT", "CT")
area <- c("red", "green", "blue")

matrix_feature_group <- matrix(nrow = 9, ncol = 3)

group_label <- c()
counter <- 0
for(iAxon in 1:3) {
  for(iArea in 1:3) {
    counter <- counter + 1
    group_label <- c(group_label, paste0(area[iArea],"-",axon_class[iAxon]))
    tmp_index <- base::intersect(which(df$Type == axon_class[iAxon]),
                                 which(df$Area == area[iArea]))
    for(iFeature in 1:3) {
      if(iFeature == 1) {
        matrix_feature_group[counter , iFeature] <- mean(df$Tuft_length[tmp_index])
      }
      if(iFeature == 2) {
        matrix_feature_group[counter , iFeature] <- mean(df$Trunk_length[tmp_index])
      }
      if(iFeature == 3) {
        matrix_feature_group[counter , iFeature] <- mean(df$Basal_length[tmp_index])
      }
    }
  }
}
matrix_feature_group_normalized <- apply(matrix_feature_group, 2, function(x) x/max(x))

rownames(matrix_feature_group_normalized) <- group_label
colnames(matrix_feature_group_normalized) <- c("Tuft", "Trunk", "Basal")

Heatmap(matrix = matrix_feature_group_normalized, cluster_rows = F, cluster_columns = F)











# correlation with other architectural features ----
cell_density_SS <- cell_density[24,-1]
cell_density_MOp <- cell_density[11,-1]
cell_density_MOp_SS <- colMeans(rbind(cell_density_MOp, cell_density_SS))

cell_density_VISp <- cell_density[145,-1]


cell_density_all <- 
  rbind(cell_density_PFC, cell_density_MOp_SS, cell_density_VISp)

rownames(cell_density_all) <- c(SourceRegion, c("MOp-SS", "VIS"))


tmpMatch_ColorSourceRegion <- 
  c("MOs"="MOs","ACAd"="ACAd","ACAv"="ACAv",
    "PL"="PL","ILA"="ILA","FRP"="FRP",
    "ORBm"="ORBm","ORBvl"="ORBvl","ORBl"="ORBl",
    "AId"="AId","AIv"="AIv",
    
    "MOp"="green","SSp-bfd"="green","SSp-ll"="green",
    "SSp-m"="green","SSp-n"="green","SSp-ul"="green",
    "SSp-un"="green", "SSp-tr"="green", "SSs"="green",
    
    "VISal"="blue", "VISam" = "blue", "VISl"="blue",
    "VISli"="blue", "VISp" = "blue", "VISpm"="blue",
    "VISpor"="blue")

df <- data.frame(
  Type = factor(x = tmpMatch_axon[match(asdf$Type, names(tmpMatch_axon))],
                levels = c("IT", "PT", "CT")),
  Total_length = feature_dendrite$dendrite_cable.length,
  Tuft_length = feature_dendrite$arbor.Length,
  Trunk_length = feature_dendrite$trunk.Length,
  Basal_length = feature_dendrite$basal_cable.length,
  Area = factor(tmpMatch_ColorSourceRegion[match(asdf$BrainRegion, names(tmpMatch_ColorSourceRegion))]))
  
  
  tmp_region <- c(SourceRegion, c("green", "blue"))
  
  length_of_dendrite_mean <- matrix(nrow = 13, ncol = 3)
  rownames(length_of_dendrite_mean) <- tmp_region
  colnames(length_of_dendrite_mean) <- c("IT","PT","CT")
  
  counter_region <- 0
  for(iRegion in tmp_region) {
    counter_region <- counter_region + 1
    counter_class <- 0
    for(iClass in c("IT","PT","CT")) {
      tmp_index <- base::intersect(which(df$Type == iClass), which(df$Area == iRegion))
      counter_class <- counter_class + 1
      length_of_dendrite_mean[counter_region, counter_class] <-
        mean(df$Total_length[tmp_index])
    }
  }


#  
  
  matrix_pvalue <- matrix(nrow = 3, ncol = 9)
  rownames(matrix_pvalue) <- c("IT", "PT", "CT")
  colnames(matrix_pvalue) <- colnames(cell_density_all)
  
  
  df_value_dendrite <- c()
  df_value_density <- c()
  df_group_dendrite <- c()
  df_group_density <- c()
  df_group_region <- c()
  
  for(iClass in 1:3) {
    for(iDensity in 1:9) {
      
      tmp_Y <- length_of_dendrite_mean[,iClass]
      tmp_X <- cell_density_all[,iDensity]
      
      
      asdf <- cor.test(x = tmp_X, y = tmp_Y)
      matrix_pvalue[iClass, iDensity] <- asdf$p.value
      
      
      df_value_dendrite <- c(df_value_dendrite, tmp_Y)
      df_value_density <- c(df_value_density, tmp_X)
      df_group_dendrite <- 
        c(df_group_dendrite, rep(x = colnames(length_of_dendrite_mean)[iClass], 13))
      df_group_density <- 
        c(df_group_density, rep(x = colnames(cell_density_PFC)[iDensity], 13))
      df_group_region <- c(df_group_region, tmp_region)
    }
  }
  
  
  df_dendrite_density <- 
    data.frame(Value_dendrite = df_value_dendrite,
               Value_density = df_value_density,
               Group_dendrite = factor(x = df_group_dendrite, levels = c("IT", "PT", "CT")),
               Group_density = df_group_density,
               Group_region = df_group_region)
  
  
  ggplot(data = df_dendrite_density, 
         mapping = aes(x = Value_dendrite, y = Value_density)) +
    #geom_point(size = 3)+
    geom_point(size = 3, aes(color = Group_region))+
    facet_wrap(~ Group_dendrite + Group_density, scales = "free", nrow = 3, ncol = 9) +
    
    geom_smooth(method = "lm") + 
    theme_classic() +
    theme(axis.text.x = element_text(size = 8), 
          axis.text.y = element_text(size = 8), 
          legend.position = "left") +
    #scale_x_continuous(breaks = get_breaks(n = 8)) + 
    scale_color_manual(values = c(ColorSourceRegion, c("green"="#00ff00", "blue"="#0000ff"))) +
    #scale_y_continuous(breaks = get_breaks(n = 6), limits = c(0, 5e5)) +
    ggpmisc::stat_fit_glance(method = "lm",
                             geom = "text_npc",
                             aes(label = paste0("P=", signif(..p.value.., digits = 4))),
                             label.x = "left",
                             label.y = "bottom") +
    ggpmisc::stat_poly_eq(aes(label = paste0(..rr.label..)), 
                          label.x = "right", 
                          label.y = "bottom")
  
  
  
  
  
## correlation with cortical thickness ----
  axon_class <- c("IT", "PT", "CT")
  tmpMatch_ColorSourceRegion <- 
    c("MOs"="red","ACAd"="red","ACAv"="red",
      "PL"="red","ILA"="red","FRP"="red",
      "ORBm"="red","ORBvl"="red","ORBl"="red",
      "AId"="red","AIv"="red",
      
      "MOp"="green","SSp-bfd"="green","SSp-ll"="green",
      "SSp-m"="green","SSp-n"="green","SSp-ul"="green",
      "SSp-un"="green", "SSp-tr"="green", "SSs"="green",
      
      "VISal"="blue", "VISam" = "blue", "VISl"="blue",
      "VISli"="blue", "VISp" = "blue", "VISpm"="blue",
      "VISpor"="blue")
  
  
thickness_soma <- read.table(file = "./CodeMatlab/figure_4_soma_thickness.txt", header = F)  
Index_valid <- which(thickness_soma > 0)  
  
library(ggplot2)
library(ggpubr)


p <- ggplot2::ggplot(data = data.frame(Thickness = thickness_soma$V1[Index_valid], 
                                  Total_Length = feature_dendrite$dendrite_cable.length[Index_valid],
                                  Type = as.factor(tmpMatch_axon[match(asdf$Type[Index_valid],
                                                                       names(tmpMatch_axon))]),
                                  Area = factor(x = tmpMatch_ColorSourceRegion[match(asdf$BrainRegion[Index_valid], 
                                                                                     names(tmpMatch_ColorSourceRegion))],
                                                levels = c("red", "green", "blue"))),
                mapping = aes(x = Total_Length, y = Thickness)) +
  facet_wrap(facets = "Type", scale = "free") +
  geom_point(aes(shape = Area, color = Type), size = 2) +
  geom_smooth(method = "lm") + 
  theme_classic() +
  theme(axis.text.x = element_text(size = 12), 
        axis.text.y = element_text(size = 12), 
        legend.position = "left") +
  #scale_x_continuous(breaks = get_breaks(n = 8)) + 
  scale_color_manual(values = c("CT"="cyan", "IT"="orange", "PT"="magenta"))+
  scale_shape_manual(values = c("red"=20, "green"=0, "blue"=2)) +
  #scale_y_continuous(breaks = get_breaks(n = 6), limits = c(0, 5e5)) +
  ggpmisc::stat_fit_glance(method = "lm",
                           geom = "text_npc",
                           aes(label = paste0("P=", signif(..p.value.., digits = 4))),
                           label.x = "left",
                           label.y = "bottom") +
  ggpmisc::stat_poly_eq(aes(label = paste0(..rr.label..)), label.x = "right", label.y = "bottom")

ggExtra::ggMarginal(p = p, groupColour = TRUE, groupFill = TRUE, margins = "x")

  

#   visualization ----
open3d()
index_neuron_PFC_IT <- base::intersect(which(asdf$BrainRegion %in% "ACAd"), which(asdf$Type %in% "ITc"))
index_neuron_PFC_PT <- base::intersect(which(asdf$BrainRegion %in% "ACAd"), which(asdf$Type %in% "PT"))
index_neuron_PFC_CT <- base::intersect(which(asdf$BrainRegion %in% "ACAd"), which(asdf$Type %in% "CT"))

index_neuron_MOp_IT <- base::intersect(which(asdf$BrainRegion %in% "MOp"), which(asdf$Type %in% "ITc"))
index_neuron_MOp_PT <- base::intersect(which(asdf$BrainRegion %in% "MOp"), which(asdf$Type %in% "PT"))
index_neuron_MOp_CT <- base::intersect(which(asdf$BrainRegion %in% "MOp"), which(asdf$Type %in% "CT"))

index_neuron_VIS_IT <- base::intersect(which(asdf$BrainRegion %in% "VISp"), which(asdf$Type %in% "ITc"))
index_neuron_VIS_PT <- base::intersect(which(asdf$BrainRegion %in% "VISp"), which(asdf$Type %in% "PT"))
index_neuron_VIS_CT <- base::intersect(which(asdf$BrainRegion %in% "VISp"), which(asdf$Type %in% "CT"))

plot(dendrite_apical_total[index_neuron_PFC_IT[1]], color = "red")
plot(dendrite_basal_total[index_neuron_PFC_IT[1]], color = "red4")


path_swc_transformed_apical_annot <- matrix(nrow = 373, ncol = 1)
path_swc_transformed_basal <- matrix(nrow = 373, ncol = 1)

asdf_non <- asdf[1575:1947,]

for(iDendrite in 1:373) {
  if(asdf_non$SampleID[iDendrite] == "Peng") {
    path_swc_transformed_apical_annot[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", asdf_non$NeuronID[iDendrite], "_apical_transformed.swc")
    path_swc_transformed_basal[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", asdf_non$NeuronID[iDendrite], "_basal_transformed.swc")
  }
  if(asdf_non$SampleID[iDendrite] == "MouseLight") {
    tmpNeuronID <- stringr::str_pad(string = asdf_non$NeuronID[iDendrite], width = 4, side = "left", pad = "0")
    
    path_swc_transformed_apical_annot[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", tmpNeuronID, "_apical_transformed.swc")
    path_swc_transformed_basal[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", tmpNeuronID, "_basal_transformed.swc")
  }
  if(asdf_non$SampleID[iDendrite] == "Allen") {
    tmpNeuronID <- asdf_non$NeuronID[iDendrite]
    
    path_swc_transformed_apical_annot[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", tmpNeuronID, "_apical_transformed.swc")
    path_swc_transformed_basal[iDendrite, 1] <- 
      paste0(asdf_non$SampleID[iDendrite], "-", tmpNeuronID, "_basal_transformed.swc")
  }
}

setwd("/home/admin/Documents/YanLab/Task_Local/LocalMorphology/visualization_non-PFC//")

Index_MOp_SS <- which(asdf_non$BrainRegion %in% c("MOp", "SSs"))[31:60]
Index_VIS <- which(asdf_non$BrainRegion %in% c("VISp"))[1:30]

plot_dendrite_2D(filename_apical = path_swc_transformed_apical_annot[c(Index_MOp_SS, Index_VIS)], 
                 filename_basal = path_swc_transformed_basal[c(Index_MOp_SS, Index_VIS)], 
                 color = "red", 
                 name = paste0(asdf_non$BrainRegion[c(Index_MOp_SS, Index_VIS)], 
                               "-", 
                               asdf_non$Type[c(Index_MOp_SS, Index_VIS)]), 
                 plane = "XZ", plot_tuft = TRUE, plot_basal = FALSE)



setwd("/home/admin/Documents/YanLab/Task_Local/LocalMorphology/visualization_clusters2/")

asdf_PFC <- asdf[1:1574,]
## read transformed SWC files ----
PFC_path_dendrite_apical <- 
  paste0(asdf_PFC$SampleID, "-", 
         stringr::str_pad(asdf_PFC$NeuronID, 3, "left", "0"),
         "_apical_transformed.swc")

PFC_path_dendrite_basal <- 
  paste0(asdf_PFC$SampleID, "-",
         stringr::str_pad(asdf_PFC$NeuronID, 3, "left", "0"),
         "_basal_transformed.swc")

plot_dendrite_2D(filename_apical = PFC_path_dendrite_apical[2:60], 
                 filename_basal = PFC_path_dendrite_basal[2:60], 
                 color = "blue", 
                 name = paste0(asdf_PFC$BrainRegion[2:60], 
                               "-", 
                               asdf_PFC$Type[2:60]), 
                 plane = "XZ", plot_tuft = FALSE, plot_basal = TRUE)








  
