# potential connectivity among PFC (both ipsi- and contra- lateral)
# figure 7B

SWCPath_dendrite <- dendrite_info$PathDendrite_allen
SWCPath_axon <- paste0("/home/admin/Documents/YanLab/database_neuron/", 
                       dendrite_info$SampleID, "/swc_allen_space/",
                       stringr::str_pad(string = dendrite_info$NeuronID, 
                                        width = 3, side = "left", pad = "0"),
                       ".swc")

NeuronName_Full_Left <- 
  paste0(dendrite_info$SampleID, "-",  
         stringr::str_pad(string = dendrite_info$NeuronID, 
                          width = 3, side = "left", pad = "0"), "-Left")

NeuronName_Full_Right <- 
  paste0(dendrite_info$SampleID, "-",  
         stringr::str_pad(string = dendrite_info$NeuronID, 
                          width = 3, side = "left", pad = "0"), "-Right")


# read dendrites ----
neuronlist_dendrite_left <- neuronlist()
neuronlist_dendrite_right <- neuronlist()


for(iNeuron in 1:1980) {
  if(iNeuron %% 100 == 0) {
    print(paste0(iNeuron, " / ", 1980))
  }
  
  tmp_dendrite <- nat::read.neuron(f = SWCPath_dendrite[iNeuron])
  
  if(dendrite_info$Hemisphere[iNeuron] == "Left") {
    tmp_dendrite$NeuronName <- NeuronName_Full_Left[iNeuron]
    neuronlist_dendrite_left[[iNeuron]] <- tmp_dendrite
    
    tmp_dendrite$NeuronName <- NeuronName_Full_Right[iNeuron]
    tmp_dendrite$d$Z <- 11400 - tmp_dendrite$d$Z
    neuronlist_dendrite_right[[iNeuron]] <- tmp_dendrite
  }
  
  
  if(dendrite_info$Hemisphere[iNeuron] == "Right") {
    tmp_dendrite$NeuronName <- NeuronName_Full_Right[iNeuron]
    neuronlist_dendrite_right[[iNeuron]] <- tmp_dendrite
    
    tmp_dendrite$NeuronName <- NeuronName_Full_Left[iNeuron]
    tmp_dendrite$d$Z <- 11400 - tmp_dendrite$d$Z
    neuronlist_dendrite_left[[iNeuron]] <- tmp_dendrite
  }
}


neuronlist_dendrite_left_and_right <- 
  c(neuronlist_dendrite_left, neuronlist_dendrite_right)


saveRDS(object = neuronlist_dendrite_left_and_right, 
        file = "/run/media/admin/LeGAO/neuronlist_dendrite_left_and_right.rds", version = 2)




open3d();
plot3d(neuronlist_dendrite_left, color = "red");
plot3d(neuronlist_dendrite_right, color = "blue")
shade3d(mesh_PFC, color = "white", alpha = 0.1)



rm(neuronlist_dendrite_left)
rm(neuronlist_dendrite_right)
rm(neuronlist_dendrite_left_and_right)
gc()





# read axons ----
neuronlist_axon_left <- neuronlist()
neuronlist_axon_right <- neuronlist()

for(iNeuron in 1:1980) {
  if(iNeuron %% 100 == 0) {
    print(paste0(iNeuron, " / ", 1980))
  }
  
  tmp_axon <- nat::read.neuron(f = SWCPath_axon[iNeuron])
  
  if(dendrite_info$Hemisphere[iNeuron] == "Left") {
    tmp_axon$NeuronName <- NeuronName_Full_Left[iNeuron]
    neuronlist_axon_left[[iNeuron]] <- tmp_axon
    
    tmp_axon$NeuronName <- NeuronName_Full_Right[iNeuron]
    tmp_axon$d$Z <- 11400 - tmp_axon$d$Z
    neuronlist_axon_right[[iNeuron]] <- tmp_axon
  }
  
  if(dendrite_info$Hemisphere[iNeuron] == "Right") {
    tmp_axon$NeuronName <- NeuronName_Full_Right[iNeuron]
    neuronlist_axon_right[[iNeuron]] <- tmp_axon
    
    tmp_axon$NeuronName <- NeuronName_Full_Left[iNeuron]
    tmp_axon$d$Z <- 11400 - tmp_axon$d$Z
    neuronlist_axon_left[[iNeuron]] <- tmp_axon
  }
}


neuronlist_axon_left_and_right <- 
  c(neuronlist_axon_left, neuronlist_axon_right)


rm(neuronlist_axon_left)
rm(neuronlist_axon_right)
gc()

saveRDS(object = neuronlist_axon_left_and_right, 
        file = "/run/media/admin/LeGAO/neuronlist_axon_left_and_right.rds", version = 2)

rm(neuronlist_axon_left_and_right)
gc()






# test 
# axon_1 <- read.neuron(f = SWCPath_axon[1])
# dendrite_1 <- read.neuron(f = SWCPath_dendrite[1])
# 
# bounds_X0 <- min(dendrite_1$d$X)
# bounds_X1 <- max(dendrite_1$d$X)
# 
# bounds_Y0 <- min(dendrite_1$d$Y)
# bounds_Y1 <- max(dendrite_1$d$Y)
# 
# bounds_Z0 <- min(dendrite_1$d$Z)
# bounds_Z1 <- max(dendrite_1$d$Z)
# 
# nat::potential_synapses(a = axon_1, b = dendrite_1, s = 2, sigma = 20, 
#                         method = "approx",
#                         bounds = c(bounds_X0, bounds_X1,
#                                    bounds_Y0, bounds_Y1,
#                                    bounds_Z0, bounds_Z1))



# read potential synapses ----
data_list_1_1000 <- readRDS("./CodeR/potential_connectivity/result/data_list_1000.Rdata")
data_list_1000_1980 <- readRDS("./CodeR/potential_connectivity/result/data_list_1000-1980.Rdata")

data_list_final <- data_list_1000_1980
data_list_final[1:999] <- data_list_1_1000[1:999]

potential_synapse <- do.call(what = "rbind", args = data_list_final)

potential_synapse <- t(potential_synapse)
potential_synapse[which(potential_synapse < 0)] <- 0

library(ComplexHeatmap)
Heatmap(t(potential_synapse), cluster_rows = F, cluster_columns = F,
        row_names_side = "left", column_names_side = "top")


table(dendrite_info$C)


label_type <- c("L23 IT", "L5 IT", "L5 PT", "L6 IT", "L6 CT")
label_column <- 1:60

label_column_type <- paste0(rep(label_column, each = 5), "-", rep(label_type, 60))


label_neuron <- matrix(nrow = 1980, ncol = 1)

for(iNeuron in 1:1980) {
  tmp_column <- dendrite_info$C[iNeuron]
  tmp_laminar <- tmpMatch_layer[match(dendrite_info$W[iNeuron], names(tmpMatch_layer))]
  tmp_type <- tmpMatch_axon[match(dendrite_info$Type[iNeuron], names(tmpMatch_axon))]
  
  label_neuron[iNeuron] <- paste0(tmp_column, "-", tmp_laminar, " ", tmp_type)
}

## ipsi ----
connection_type_ipsi <- matrix(nrow = 300, ncol = 300)
connection_raw_ipsi <- list()

counter <- 0
for(iLabelAxon in 1:300) {
  tmp_index_axon <- which(label_neuron == label_column_type[iLabelAxon])
  for(iLabelDendrite in 1:300) {
    tmp_index_dendrite <- which(label_neuron == label_column_type[iLabelDendrite])
    
    if(length(tmp_index_axon) < 1 || length(tmp_index_dendrite) < 1) {
      connection_type_ipsi[iLabelAxon, iLabelDendrite] <- NA
      
      counter <- counter + 1
      connection_raw_ipsi[[counter]] <- NA
    } else {
      connection_type_ipsi[iLabelAxon, iLabelDendrite] <- 
        mean(potential_synapse[tmp_index_axon, tmp_index_dendrite])
      
      counter <- counter + 1
      connection_raw_ipsi[[counter]] <- potential_synapse[tmp_index_axon, tmp_index_dendrite]
    }
  }
}


# exclude PFC units with few neurons ----
tmp_index_invalid <- c()
for(iRow in 1:300) {
  tmp_length <- length(which(is.na(connection_type_ipsi[iRow,]) == TRUE))
  if(tmp_length == 300) {
    tmp_index_invalid <- c(tmp_index_invalid, iRow)
  }
}




## contra ----
potential_synapse_contra <- potential_synapse[1981:3960,]

connection_type_contra <- matrix(nrow = 300, ncol = 300)
connection_raw_contra <- list()

counter <- 0
for(iLabelAxon in 1:300) {
  tmp_index_axon <- which(label_neuron == label_column_type[iLabelAxon])
  for(iLabelDendrite in 1:300) {
    tmp_index_dendrite <- which(label_neuron == label_column_type[iLabelDendrite])
    
    
    if(length(tmp_index_axon) < 1 || length(tmp_index_dendrite) < 1) {
      connection_type_contra[iLabelAxon, iLabelDendrite] <- NA
      
      counter <- counter + 1
      connection_raw_contra[[counter]] <- NA
    } else {
      connection_type_contra[iLabelAxon, iLabelDendrite] <- 
        mean(potential_synapse_contra[tmp_index_axon, tmp_index_dendrite])
      
      counter <- counter + 1
      connection_raw_contra[[counter]] <- 
        potential_synapse_contra[tmp_index_axon, tmp_index_dendrite] 
    }
  }
}


library(ComplexHeatmap)
Heatmap(connection_type_contra, cluster_rows = F, cluster_columns = F,
        row_names_side = "left", column_names_side = "top")





## exclude columns with few neurons ----

column_invalid <- unique(rep(label_column, each = 5)[tmp_index_invalid])
column_valid <- setdiff(1:60, c(column_invalid, 31, 45))


label_column_all <- rep(1:60, each = 5)


tmp_connection_type_ipsi <- 
  connection_type_ipsi[which(label_column_all %in% column_valid), 
                       which(label_column_all %in% column_valid)]

column_names <- rep(column_valid, each = 5)


order_unit <- c(1,2,5,17,35,36,38,47,60, # red
                7,12,14,16,19,22,48,56, # green
                8,20,33,41 # blue
                )

valid_names <- paste0(rep(order_unit, each = 5), "-", rep(label_type, length(order_unit)))



tmp_connection_type_ipsi_ordered <- 
  connection_type_ipsi[match(valid_names, label_column_type), 
                           match(valid_names, label_column_type)]


tmp_connection_type_contra_ordered <- 
  connection_type_contra[match(valid_names, label_column_type), 
                             match(valid_names, label_column_type)]


tmp_connection_type_contra <- 
  connection_type_contra[which(label_column_all %in% column_valid), 
                         which(label_column_all %in% column_valid)]





library(ComplexHeatmap)
Heatmap(rbind(tmp_connection_type_ipsi_ordered, 
              tmp_connection_type_contra_ordered), 
        top_annotation = HeatmapAnnotation(Column = factor(x = rep(order_unit, each = 5),
                                                           levels = order_unit)#,
                                           #Type = label_type_all#,
                                           #col = list(Cluster = ColorCluster_K25,
                                           #            Subtype = ColorClassLaminar)
        ),
        left_annotation = rowAnnotation(Column = factor(x = c(rep(order_unit, each = 5),
                                                              rep(order_unit, each = 5)),
                                                        levels = order_unit)),
        #                                     Type = c(label_type_all,
        #                                              rep(c("L23 IT", "L5 IT", "L6 IT"), 60)),
        #                                     which = "row"
        #                                     #col = list(Cluster = ColorCluster_K25,
        #                                     #            Subtype = ColorClassLaminar)
        #                                   ),
        row_split = c(rep("0Ipsi", 105), rep("1Contra", 105)),
        cluster_rows = F, cluster_columns = F,
        row_names_side = "left", column_names_side = "top", use_raster = T, width = 5, height = 10, 
        gap = unit(0, "mm"))






library(ComplexHeatmap)
Heatmap(rbind(connection_type_ipsi[which(label_column_all %in% column_valid), 
                                   which(label_column_all %in% column_valid)], 
              connection_type_contra[which(label_column_all %in% column_valid), 
                                     which(label_column_all %in% column_valid)]), 
        top_annotation = HeatmapAnnotation(Column = factor(x = rep(column_valid, each = 5),
                                                            levels = column_valid)#,
                                           #Type = label_type_all#,
                                           #col = list(Cluster = ColorCluster_K25,
                                          #            Subtype = ColorClassLaminar)
                                          ),
        # left_annotation = HeatmapAnnotation(Column = factor(x = c(rep(1:60, each = 5),
        #                                                           rep(1:60, each = 3)),
        #                                                     levels = 1:60),
        #                                     Type = c(label_type_all,
        #                                              rep(c("L23 IT", "L5 IT", "L6 IT"), 60)),
        #                                     which = "row"
        #                                     #col = list(Cluster = ColorCluster_K25,
        #                                     #            Subtype = ColorClassLaminar)
        #                                   ),
        cluster_rows = F, cluster_columns = F,
        row_names_side = "left", column_names_side = "top", use_raster = T)


label_type_all <- rep(c("L23 IT", "L5 IT", "L5 PT", "L6 IT", "L6 CT"), 60)





max(connection_type_contra[which(label_type_all %in% c("L5 PT")),], na.rm = T)




